---
name: Bug report
about: Report a bug
title: ''
labels: bug
assignees: ''

---

### Describe the bug
A clear and concise description of what the bug is.

### Debug information
- hypertic version: (e.g. `0.0.1`)
- Python version: (e.g. Python 3.10)

### Repro steps
Ideally provide a minimal python script that can be run to reproduce the bug.

### Expected behavior
A clear and concise description of what you expected to happen.

### Additional context
Add any other context about the problem here.